@@ -16,12 +16,27 @@ utils::globalVariables(c(
   # generate_scatter_plot
   "geom_text", 
   
-  # topicsScatterLegendNew
+  # topicsTest
+  "binomial", 
+  
+  # topicsScatterLegend
   "contains_only", 
   
   # General
   "msg2",
   
+  # create_plots
+  "color",
+  
+  "color_categories1",
+  
   # topicsDtmEval
-  "nr", "term", "freq"
+  "nr", "term", "freq",
+  
+  # topicsGrams
+  "n", "component_prob", "joint_prob", "n_gram_type", "ngrams", "pmi_value", ":=",
+  
+  # topicsPlot
+  "pmi"
+  
 ))
